pub struct TransactionKey(/* private fields */);Trait Implementations
Sourceimpl Clone for TransactionKey
impl Clone for TransactionKey
Sourcefn clone(&self) -> TransactionKey
fn clone(&self) -> TransactionKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TransactionKey
Sourceimpl Debug for TransactionKey
impl Debug for TransactionKey
Sourceimpl Default for TransactionKey
impl Default for TransactionKey
Sourcefn default() -> TransactionKey
fn default() -> TransactionKey
Returns the “default value” for a type. Read more
impl Eq for TransactionKey
Sourceimpl From<KeyData> for TransactionKey
impl From<KeyData> for TransactionKey
Sourceimpl Hash for TransactionKey
impl Hash for TransactionKey
Sourceimpl Key for TransactionKey
impl Key for TransactionKey
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for TransactionKey
impl Ord for TransactionKey
Sourcefn cmp(&self, other: &TransactionKey) -> Ordering
fn cmp(&self, other: &TransactionKey) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TransactionKey
impl PartialEq for TransactionKey
Sourceimpl PartialOrd for TransactionKey
impl PartialOrd for TransactionKey
impl StructuralPartialEq for TransactionKey