#[repr(C)]pub struct ClientLogon {
pub worker_count: usize,
pub allocator_size: usize,
pub allocator_handles: usize,
pub tpu_to_pack_capacity: usize,
pub progress_tracker_capacity: usize,
pub pack_to_worker_capacity: usize,
pub worker_to_pack_capacity: usize,
pub flags: u16,
}Expand description
The logon message sent by the client to the server.
Fields
worker_count: usizeThe number of Agave worker threads that will be spawned to handle packing requests.
allocator_size: usizeThe minimum allocator file size in bytes, this is shared by all allocator handles.
allocator_handles: usizeThe number of rts_alloc::Allocator handles the external process is requesting.
tpu_to_pack_capacity: usizeThe minimum capacity of the tpu_to_pack queue in messages.
progress_tracker_capacity: usizeThe minimum capacity of the progress_tracker queue in messages.
pack_to_worker_capacity: usizeThe minimum capacity of the pack_to_worker queue in messages.
worker_to_pack_capacity: usizeThe minimum capacity of the worker_to_pack queue in messages.
flags: u16Flags that control the behavior of the new scheduling session.
Implementations
Sourceimpl ClientLogon
impl ClientLogon
pub fn try_from_bytes(buffer: &[u8]) -> Option<Self>