TransactionPtr

Struct TransactionPtr 

pub struct TransactionPtr { /* private fields */ }

Implementations

Source

impl TransactionPtr

pub unsafe fn from_raw_parts(ptr: NonNull<u8>, count: usize) -> Self

Constructions a TransactionPtr from raw parts.

Safety
  • ptr must be valid for reads.
  • count must be accurate and not overrun the end of ptr.
Note

If you are trying to construct a pointer for use by Agave, you almost certainly want to use Self::from_sharable_transaction_region.

pub unsafe fn from_sharable_transaction_region( sharable_transaction_region: &SharableTransactionRegion, allocator: &Allocator, ) -> Self

Safety
  • sharable_transaction_region must reference a valid offset and length within the allocator.
pub unsafe fn to_sharable_transaction_region( &self, allocator: &Allocator, ) -> SharableTransactionRegion

Translate the ptr type into a sharable region.

Safety
  • allocator must be the allocator owning the memory region pointed to by self.
pub unsafe fn free(self, allocator: &Allocator)

Frees the memory region pointed to in the allocator. This should only be called by the owner of the memory i.e. the external scheduler.

Safety
  • Data region pointed to by TransactionPtr belongs to the allocator.
  • Inner ptr must not have been previously freed.