TransactionPtrBatch

Struct TransactionPtrBatch 

pub struct TransactionPtrBatch<'a, M = ()> { /* private fields */ }
A batch of transaction pointers that can be iterated over.

Implementations

Source

impl<'a, M> TransactionPtrBatch<'a, M>

pub const TRANSACTION_CORE_SIZE: usize

pub const TRANSACTION_CORE_END: usize

pub const TRANSACTION_META_START: usize

pub const TRANSACTION_META_SIZE: usize

pub const TRANSACTION_META_END: usize

pub unsafe fn from_sharable_transaction_batch_region( sharable_transaction_batch_region: &SharableTransactionBatchRegion, allocator: &'a Allocator, ) -> Self

Safety
pub const fn len(&self) -> usize

The number of transactions in this batch.

pub const fn is_empty(&self) -> bool

Whether the batch is empty.

pub fn iter(&'a self) -> impl Iterator<Item = (TransactionPtr, M)> + 'a

Iterator returning TransactionPtr for each transaction in the batch.

pub unsafe fn free(self)

Free the transaction batch container.

Safety
Note

This will not free the underlying transactions as their lifetimes may be differ from that of the batch.