pub struct TransactionPtrBatch<'a, M = ()> { /* private fields */ }Expand description
A batch of transaction pointers that can be iterated over.
Implementations
Sourceimpl<'a, M> TransactionPtrBatch<'a, M>
impl<'a, M> TransactionPtrBatch<'a, M>
pub const TRANSACTION_CORE_SIZE: usize
pub const TRANSACTION_CORE_END: usize
pub const TRANSACTION_META_START: usize
pub const TRANSACTION_META_SIZE: usize
pub const TRANSACTION_META_END: usize
Sourcepub unsafe fn from_sharable_transaction_batch_region(
sharable_transaction_batch_region: &SharableTransactionBatchRegion,
allocator: &'a Allocator,
) -> Self
pub unsafe fn from_sharable_transaction_batch_region( sharable_transaction_batch_region: &SharableTransactionBatchRegion, allocator: &'a Allocator, ) -> Self
Safety
SharableTransactionBatchRegionmust reference a valid offset and length within theallocator.- ALL
SharableTransactionRegionwithin the batch must be valid. SeeTransactionPtr::from_sharable_transaction_regionfor details. Mmust match the actualMused within this allocation.
Sourcepub fn iter(&'a self) -> impl Iterator<Item = (TransactionPtr, M)> + 'a
pub fn iter(&'a self) -> impl Iterator<Item = (TransactionPtr, M)> + 'a
Iterator returning TransactionPtr for each transaction in the batch.
Sourcepub unsafe fn free(self)
pub unsafe fn free(self)
Free the transaction batch container.
Safety
SharableTransactionBatchRegionmust be exclusively owned by this pointer.
Note
This will not free the underlying transactions as their lifetimes may be differ from that of the batch.